==> zio-aws-mediatailor_3-5.17.103.1-sources.jar: zio/aws/mediatailor/model/StopChannelRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class StopChannelRequest(channelName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.StopChannelRequest = {
    import StopChannelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.StopChannelRequest
      .builder()
      .channelName(__string.unwrap(channelName): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.StopChannelRequest.ReadOnly =
    zio.aws.mediatailor.model.StopChannelRequest.wrap(buildAwsValue())
}
object StopChannelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.StopChannelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.StopChannelRequest =
      zio.aws.mediatailor.model.StopChannelRequest(channelName)
    def channelName: __string
    def getChannelName: ZIO[Any, Nothing, __string] = ZIO.succeed(channelName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.StopChannelRequest
  ) extends zio.aws.mediatailor.model.StopChannelRequest.ReadOnly {
    override val channelName: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.channelName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.StopChannelRequest
  ): zio.aws.mediatailor.model.StopChannelRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-mediatailor_3-6.20.47.1-sources.jar: zio/aws/mediatailor/model/StopChannelRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class StopChannelRequest(channelName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.StopChannelRequest = {
    import StopChannelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.StopChannelRequest
      .builder()
      .channelName(channelName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.StopChannelRequest.ReadOnly =
    zio.aws.mediatailor.model.StopChannelRequest.wrap(buildAwsValue())
}
object StopChannelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.StopChannelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.StopChannelRequest =
      zio.aws.mediatailor.model.StopChannelRequest(channelName)
    def channelName: __string
    def getChannelName: ZIO[Any, Nothing, __string] = ZIO.succeed(channelName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.StopChannelRequest
  ) extends zio.aws.mediatailor.model.StopChannelRequest.ReadOnly {
    override val channelName: __string = impl.channelName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.StopChannelRequest
  ): zio.aws.mediatailor.model.StopChannelRequest.ReadOnly = new Wrapper(impl)
}
